```cpp
// [Test Link](BROKEN_CPP_FENCE_LINK)
#include <iostream>
int main(int argc, char **argv) {
    std::cout << "Hello, world!" << std::endl;
    return 0;
}
```

[Link should work](my-section.md)

```
[Link should not be altered](my-section.md)
[[Link should not be altered]]
![](puppy)
![Puppy](puppy)
```

Link won't work:
`![[puppy]]`

`
![[Puppy]]
`
```
```

![[Puppy]]

